@@ -13,27 +13,25 @@ def register_models():
     models = apps.get_models()
     
     for model in models:
-        print(isinstance(model(),BaseModel))
+
         if isinstance(model(),BaseModel):
             try:
                 if model.__name__ not in exclude_models:
                     
                     if not model.exclude_model:
-                        print(model)
+
                         if model.all_cruds_types:
                             urlpatterns += model().build_generics_urls_crud()
                             urlpatterns += model().build_generics_urls_ajax_crud()
-                            print(urlpatterns)
                         
                         else:
                             
                             if model.ajax_crud:         
                                 urlpatterns += model().build_generics_urls_ajax_crud()
                             if model.normal_cruds:
-                                urlpatterns += model().build_generics_urls_crud()
-                            
-                            print(urlpatterns)
+                                urlpatterns += model().build_generics_urls_crud()                            
+
             except:
                 pass
-    print(urlpatterns)
+
     return urlpatterns
\ No newline at end of file
