@@ -131,6 +131,9 @@ class BaseUpdate(BaseCrudMixin,UpdateView):
         form = get_form(form,self.model)
         form = form(instance = get_object(self.model,self.kwargs['pk']))
         
+        if context['object'] == None:
+            return redirect(self.success_url)
+        
         context = self.get_context_data()
         context['form'] = form
         return render(request,self.template_name,context)
@@ -190,7 +193,7 @@ class BaseLogicDelete(BaseCrudMixin,DeleteView):
         instance = get_object(self.model,self.kwargs['pk'])
         
         if instance is not None:
-            instance.update(model_state = False)
+            self.model.objects.filter(id = self.kwargs['pk']).update(model_state = False)
             return redirect(self.success_url)        
         else:
             return redirect(self.success_url)
\ No newline at end of file
